
################# # IMPORTS # #################

library(dplyr)
library(googlesheets4)
library(lubridate)
library(plotly)
library(scales)
library(tidyverse)
library(viridis)

cropland <- read_csv("data/output/cropland_final_for_exact.csv")

non_nitrogen_fertilizer <- tribble(~"Year",~"Type",~"Tonnes",
                                   2019, "limestone",	16329, # data from VTAAFM 2019 Fert Report
                                   2019, "phosphorus",	1993,
                                   2019, "potassium",	4137,
)

nitrogen_fertilizer = read_csv("data/input/fertilizer_nitrogen_input.csv") %>% 
  transmute(Year,nitrogen = Tonnes)

total_cropland <- cropland %>% 
  group_by(Year) %>% 
  summarize(ha = sum(ha))

fertilizer_ratios <- total_cropland %>% 
  filter(Year == 2019) %>% 
  left_join(non_nitrogen_fertilizer) %>% 
  transmute(f_ratios = Tonnes/ha, Type) %>% 
  spread(Type,f_ratios)


fertilizer_final <- total_cropland %>% 
  cbind(fertilizer_ratios) %>% 
  mutate(limestone = limestone * ha,
         phosphorus = phosphorus * ha,
         potassium = potassium * ha) %>% 
  left_join(nitrogen_fertilizer) %>% 
  select(Year,nitrogen,limestone,phosphorus,potassium)

fertilizer_final %>% 
  write_csv("data/output/fertilizer_final_for_exact.csv")

